import { NS } from "@ns"
import {parse} from "./lib/flag"
import {range} from "./util/range";


/** @param {NS} ns */
export async function main(ns: NS): Promise<void> {
    const flag = parse(ns.args);
    if(flag.h || flag.help){
        ns.tprint("script : purchase server")
        ns.tprint("");
        ns.exit()
    }
    if(Boolean(flag.i) || Boolean(flag.interactive)){
        const ramLimit = ns.getPurchasedServerMaxRam()
        const choices = [...range(3,20)].map(x=>Math.pow(2,x)).filter(x=>x <= ramLimit).map((x)=>{
            const cost = ns.getPurchasedServerCost(x);
            return `${x}GB (${ns.nFormat(cost,"$0.000a")})`
        });
        const choice = await ns.prompt("which server do you purchase?",{
            type:"select",
            choices
        });
        if(choice === ""){
            ns.tprint("canceled");
            ns.exit();
            return;
        }
        const gb = parseInt(/^(\d+)GB/.exec(choice)[1]);
        ns.tprint("you select ",gb,"GB");
        const hostname = await ns.prompt("name your server",{type:"text"});
        if(hostname === ""){
            ns.tprint("canceled");
            ns.exit();
            return;
        }
        const p = await ns.prompt(
            `do you want to purchase server ${gb}GB(${
                ns.nFormat(ns.getPurchasedServerCost(gb),"$0.000a")})?`,
        { type: "boolean" });
        if (p) {
            const l = ns.purchaseServer(hostname, ram)
            ns.tprint(l, " purchased");
        }
        ns.exit()
        return;
    }
    
    if ((flag.n || flag.name) && (flag.s || flag.size)) {
        ns.tprint("argument needed")
        ns.tprint("run cmd -n [hostname] -s [ram(GB)]")
        ns.tprint("run cmd --name [hostname] --size [ram(GB)]")
        ns.exit()
        return;
    }

    const hostname = flag.n ?? flag.name 
    const ram = parseInt(flag.s ?? flag.size)
    if(isNaN(ram)){
        ns.tprint("size must be integer!");
        ns.exit();
        return;
    }
    const f = ns.getPurchasedServerCost(ram)
    const ff = ns.nFormat(f, "($ 0.00 a)")
    const p = await ns.prompt("required : " + ff + "\ndo you want to purchase server " + ram + "GB?",
    { type: "boolean" })
    if (p) {
        const l = ns.purchaseServer(hostname, ram)
        ns.tprint(l, " purchased")
    }
}